pub(crate) struct DiskCache {
path: PathBuf,
max_size: usize,
inner: Mutex<DiskCacheInner>,
}Expand description
A struct representing the disk cache.
Fields
path: PathBufmax_size: usizeinner: Mutex<DiskCacheInner>Implementations
Sourceimpl DiskCache
impl DiskCache
Sourcepub(crate) fn new(
cache_assignment: HttpCacheAssignment,
) -> (Option<Arc<DiskCache>>, MemoryCacheLifecycle)
pub(crate) fn new( cache_assignment: HttpCacheAssignment, ) -> (Option<Arc<DiskCache>>, MemoryCacheLifecycle)
Creates a new DiskCache if the preference if set.
Creates the sqlite table if it does not exist and starts the db connection.
TODO: Implement WAL and other sqlite pragma.
Sourcepub(crate) async fn get(
&self,
key: CacheKey,
) -> Option<Arc<TokioRwLock<Vec<CachedResource>>>>
pub(crate) async fn get( &self, key: CacheKey, ) -> Option<Arc<TokioRwLock<Vec<CachedResource>>>>
Restores a cache entry from the disk if it exists. Deletes the entry from the disk cache
Sourcepub(crate) async fn store(
&self,
key: CacheKey,
entry: Arc<RwLock<Vec<CachedResource>>>,
)
pub(crate) async fn store( &self, key: CacheKey, entry: Arc<RwLock<Vec<CachedResource>>>, )
Stores a CacheEntry` to disk.
Sourceasync fn delete_until_cache_size(&self)
async fn delete_until_cache_size(&self)
Deletes data from the cache until the size is <= max_size
Sourcefn get_disk_cache_total_size(&self, conn: &Connection) -> Option<usize>
fn get_disk_cache_total_size(&self, conn: &Connection) -> Option<usize>
Queries the current disk cache size from the sql database.