struct DiskCacheInner {
entries: VecDeque<DiskCacheMetadata>,
size: usize,
db: Connection,
cache_assignment: HttpCacheAssignment,
}Expand description
This data structure will be per HttpCacheAssignment. Currently, we only store HttpCacheAssignment::Public and otherwise return zero.
As this data structure stores the state of the cache, if other instances share the same sqlite database, special care has to be taken
to ensure conistency.
Fields
entries: VecDeque<DiskCacheMetadata>size: usizedb: Connectioncache_assignment: HttpCacheAssignmentTrait Implementations
Sourceimpl MallocSizeOf for DiskCacheInner
impl MallocSizeOf for DiskCacheInner
Sourcefn size_of(&self, ops: &mut MallocSizeOfOps) -> usize
fn size_of(&self, ops: &mut MallocSizeOfOps) -> usize
Measure the heap usage of all descendant heap-allocated structures, but
not the space taken up by the value itself.